@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-#
 # This file describes eFuses controller for ESP32 chip
 #
 # SPDX-FileCopyrightText: 2020-2022 Espressif Systems (Shanghai) CO LTD
@@ -10,6 +8,7 @@ import time
 
 from .mem_definition import EfuseDefineBlocks, EfuseDefineFields, EfuseDefineRegisters
 from ..emulate_efuse_controller_base import EmulateEfuseControllerBase, FatalError
+from esptool.logger import log
 
 
 class EmulateEfuseController(EmulateEfuseControllerBase):
@@ -18,21 +17,30 @@ class EmulateEfuseController(EmulateEfuseControllerBase):
     CHIP_NAME = "ESP32"
     mem = None
     debug = False
-    Blocks = EfuseDefineBlocks
-    Fields = EfuseDefineFields
-    REGS = EfuseDefineRegisters
 
     def __init__(self, efuse_file=None, debug=False):
+        self.Blocks = EfuseDefineBlocks
+        self.Fields = EfuseDefineFields(None)
+        self.REGS = EfuseDefineRegisters
         super(EmulateEfuseController, self).__init__(efuse_file, debug)
 
     """ esptool method start >> """
 
-    def get_chip_description(self):
-        return "revision 3"
+    def get_major_chip_version(self):
+        return 3
+
+    def get_minor_chip_version(self):
+        return 0
 
     def get_crystal_freq(self):
         return 40  # MHz (common for all chips)
 
+    def read_reg(self, addr):
+        if addr == self.REGS.APB_CTL_DATE_ADDR:
+            return self.REGS.APB_CTL_DATE_V << self.REGS.APB_CTL_DATE_S
+        else:
+            return super(EmulateEfuseController, self).read_reg(addr)
+
     """ << esptool method end """
 
     def send_burn_cmd(self):
@@ -42,7 +50,7 @@ class EmulateEfuseController(EmulateEfuseControllerBase):
                 if self.read_reg(self.REGS.EFUSE_REG_CMD) == 0:
                     return
             raise FatalError(
-                "Timed out waiting for Efuse controller command to complete"
+                "Timed out waiting for eFuse controller command to complete"
             )
 
         self.write_reg(self.REGS.EFUSE_REG_CMD, self.REGS.EFUSE_CMD_WRITE)
@@ -63,10 +71,14 @@ class EmulateEfuseController(EmulateEfuseControllerBase):
                 self.save_to_file()
 
     def read_raw_coding_scheme(self):
-        return (
+        coding_scheme = (
             self.read_efuse(self.REGS.EFUSE_CODING_SCHEME_WORD)
             & self.REGS.EFUSE_CODING_SCHEME_MASK
         )
+        if coding_scheme == self.REGS.CODING_SCHEME_NONE_RECOVERY:
+            return self.REGS.CODING_SCHEME_NONE
+        else:
+            return coding_scheme
 
     def write_raw_coding_scheme(self, value):
         self.write_efuse(
@@ -78,7 +90,7 @@ class EmulateEfuseController(EmulateEfuseControllerBase):
             raise FatalError(
                 "Error during a burning process to set the new coding scheme"
             )
-        print("Set coding scheme = %d" % self.read_raw_coding_scheme())
+        log.print(f"Set coding scheme = {self.read_raw_coding_scheme()}")
 
     def get_bitlen_of_block(self, blk, wr=False):
         if blk.id == 0:
@@ -93,9 +105,7 @@ class EmulateEfuseController(EmulateEfuseControllerBase):
                 else:
                     return 32 * blk.len * 3 // 4
             else:
-                raise FatalError(
-                    "The {} coding scheme is not supported".format(coding_scheme)
-                )
+                raise FatalError(f"The {coding_scheme} coding scheme is not supported")
 
     def handle_coding_scheme(self, blk, data):
         # it verifies the coding scheme part of data and returns just data
@@ -114,7 +124,7 @@ class EmulateEfuseController(EmulateEfuseControllerBase):
                     xor_res ^= byte_data
                     mul_res += (i + 1) * bin(byte_data).count("1")
                 if xor_res != chunk_data[6] or mul_res != chunk_data[7]:
-                    print(
+                    log.print(
                         "xor_res ",
                         xor_res,
                         chunk_data[6],
