@@ -8,10 +8,11 @@ import binascii
 import struct
 import sys
 import time
-from typing import List, Tuple, Optional
+
 from bitstring import BitArray
 
 import esptool
+from esptool.logger import log
 
 import reedsolo
 
@@ -55,9 +56,6 @@ class EspEfuses(base_fields.EspEfusesBase):
     Wrapper object to manage the efuse fields in a connected ESP bootloader
     """
 
-    debug = False
-    do_not_confirm = False
-
     def __init__(
         self,
         esp,
@@ -66,14 +64,12 @@ class EspEfuses(base_fields.EspEfusesBase):
         do_not_confirm=False,
         extend_efuse_table=None,
     ):
+        super().__init__(esp, skip_connect, debug, do_not_confirm, extend_efuse_table)
         self.Blocks = EfuseDefineBlocks()
         self.Fields = EfuseDefineFields(extend_efuse_table)
         self.REGS = EfuseDefineRegisters
         self.BURN_BLOCK_DATA_NAMES = self.Blocks.get_burn_block_data_names()
         self.BLOCKS_FOR_KEYS = self.Blocks.get_blocks_for_keys()
-        self._esp = esp
-        self.debug = debug
-        self.do_not_confirm = do_not_confirm
         if esp.CHIP_NAME != "ESP32-C5":
             raise esptool.FatalError(
                 "Expected the 'esp' param for ESP32-C5 chip but got for '%s'."
@@ -136,14 +132,14 @@ class EspEfuses(base_fields.EspEfusesBase):
         self.coding_scheme = self.REGS.CODING_SCHEME_RS
 
     def print_status_regs(self):
-        print("")
+        log.print("")
         self.blocks[0].print_block(self.blocks[0].err_bitarray, "err__regs", debug=True)
-        print(
+        log.print(
             "{:27} 0x{:08x}".format(
                 "EFUSE_RD_RS_ERR0_REG", self.read_reg(self.REGS.EFUSE_RD_RS_ERR0_REG)
             )
         )
-        print(
+        log.print(
             "{:27} 0x{:08x}".format(
                 "EFUSE_RD_RS_ERR1_REG", self.read_reg(self.REGS.EFUSE_RD_RS_ERR1_REG)
             )
@@ -176,7 +172,7 @@ class EspEfuses(base_fields.EspEfusesBase):
                     # For PGM_CMD it is not necessary.
                     return
         raise esptool.FatalError(
-            "Timed out waiting for Efuse controller command to complete"
+            "Timed out waiting for eFuse controller command to complete"
         )
 
     def efuse_program(self, block):
@@ -204,30 +200,30 @@ class EspEfuses(base_fields.EspEfusesBase):
             try:
                 self._esp = self.reconnect_chip(self._esp)
             except esptool.FatalError:
-                print("Can not re-connect to the chip")
+                log.print("Can not re-connect to the chip.")
                 if not self["DIS_DOWNLOAD_MODE"].get() and self[
                     "DIS_DOWNLOAD_MODE"
                 ].get(from_read=False):
-                    print(
+                    log.print(
                         "This is the correct behavior as we are actually burning "
-                        "DIS_DOWNLOAD_MODE which disables the connection to the chip"
+                        "DIS_DOWNLOAD_MODE which disables the connection to the chip."
                     )
-                    print("DIS_DOWNLOAD_MODE is enabled")
-                    print("Successful")
+                    log.print("DIS_DOWNLOAD_MODE is enabled.")
+                    log.print("Successful.")
                     sys.exit(0)  # finish without errors
                 raise
 
-            print("Established a connection with the chip")
+            log.print("Established a connection with the chip.")
             if self._esp.secure_download_mode and not secure_download_mode_before:
-                print("Secure download mode is enabled")
+                log.print("Secure download mode is enabled.")
                 if not self["ENABLE_SECURITY_DOWNLOAD"].get() and self[
                     "ENABLE_SECURITY_DOWNLOAD"
                 ].get(from_read=False):
-                    print(
-                        "espefuse tool can not continue to work in Secure download mode"
+                    log.print(
+                        "espefuse can not continue to work in Secure download mode."
                     )
-                    print("ENABLE_SECURITY_DOWNLOAD is enabled")
-                    print("Successful")
+                    log.print("ENABLE_SECURITY_DOWNLOAD is enabled.")
+                    log.print("Successful.")
                     sys.exit(0)  # finish without errors
             raise
 
@@ -280,7 +276,7 @@ class EspEfuses(base_fields.EspEfusesBase):
                 block.num_errors = (reg_value >> err_num_offs) & err_num_mask
             ret_fail |= block.fail
             if not silent and (block.fail or block.num_errors):
-                print(
+                log.print(
                     "Error(s) in BLOCK%d [ERRORS:%d FAIL:%d]"
                     % (block.id, block.num_errors, block.fail)
                 )
@@ -301,20 +297,55 @@ class EfuseField(base_fields.EfuseFieldBase):
             "keypurpose": EfuseKeyPurposeField,
             "t_sensor": EfuseTempSensor,
             "adc_tp": EfuseAdcPointCalibration,
-            "wafer": EfuseWafer,
+            "recovery_bootloader": EfuseBtldrRecoveryField,
+            "bootloader_anti_rollback": EfuseBtldrAntiRollbackField,
         }.get(efuse.class_type, EfuseField)(parent, efuse)
 
 
-class EfuseWafer(EfuseField):
+class EfuseBtldrRecoveryField(EfuseField):
     def get(self, from_read=True):
-        hi_bits = self.parent["WAFER_VERSION_MINOR_HI"].get(from_read)
-        assert self.parent["WAFER_VERSION_MINOR_HI"].bit_len == 1
-        lo_bits = self.parent["WAFER_VERSION_MINOR_LO"].get(from_read)
-        assert self.parent["WAFER_VERSION_MINOR_LO"].bit_len == 3
+        hi_bits = self.parent["RECOVERY_BOOTLOADER_FLASH_SECTOR_HI"].get(from_read)
+        assert self.parent["RECOVERY_BOOTLOADER_FLASH_SECTOR_HI"].bit_len == 3
+        lo_bits = self.parent["RECOVERY_BOOTLOADER_FLASH_SECTOR_LO"].get(from_read)
+        assert self.parent["RECOVERY_BOOTLOADER_FLASH_SECTOR_LO"].bit_len == 9
+        return (hi_bits << 9) + lo_bits
+
+    def save(self, new_value):
+        efuse = self.parent["RECOVERY_BOOTLOADER_FLASH_SECTOR_HI"]
+        efuse.save((new_value >> 9) & 3)
+        log.print(
+            f"\t    - '{efuse.name}' {efuse.get_bitstring()} -> {efuse.get_bitstring(from_read=False)}"
+        )
+        efuse = self.parent["RECOVERY_BOOTLOADER_FLASH_SECTOR_LO"]
+        efuse.save(new_value & 0x1FF)
+        log.print(
+            f"\t    - '{efuse.name}' {efuse.get_bitstring()} -> {efuse.get_bitstring(from_read=False)}"
+        )
+
+
+class EfuseBtldrAntiRollbackField(EfuseField):
+    def get(self, from_read=True):
+        hi_bits = self.parent["BOOTLOADER_ANTI_ROLLBACK_SECURE_VERSION_HI"].get(
+            from_read
+        )
+        assert self.parent["BOOTLOADER_ANTI_ROLLBACK_SECURE_VERSION_HI"].bit_len == 1
+        lo_bits = self.parent["BOOTLOADER_ANTI_ROLLBACK_SECURE_VERSION_LO"].get(
+            from_read
+        )
+        assert self.parent["BOOTLOADER_ANTI_ROLLBACK_SECURE_VERSION_LO"].bit_len == 3
         return (hi_bits << 3) + lo_bits
 
     def save(self, new_value):
-        raise esptool.FatalError("Burning %s is not supported" % self.name)
+        efuse = self.parent["BOOTLOADER_ANTI_ROLLBACK_SECURE_VERSION_HI"]
+        efuse.save((new_value >> 3) & 1)
+        log.print(
+            f"\t    - '{efuse.name}' {efuse.get_bitstring()} -> {efuse.get_bitstring(from_read=False)}"
+        )
+        efuse = self.parent["BOOTLOADER_ANTI_ROLLBACK_SECURE_VERSION_LO"]
+        efuse.save(new_value & 0x7)
+        log.print(
+            f"\t    - '{efuse.name}' {efuse.get_bitstring()} -> {efuse.get_bitstring(from_read=False)}"
+        )
 
 
 class EfuseTempSensor(EfuseField):
@@ -364,7 +395,7 @@ class EfuseMacField(EfuseField):
     def check(self):
         errs, fail = self.parent.get_block_errors(self.block)
         if errs != 0 or fail:
-            output = "Block%d has ERRORS:%d FAIL:%d" % (self.block, errs, fail)
+            output = f"Block{self.block} has ERRORS:{errs} FAIL:{fail}."
         else:
             output = "OK"
         return "(" + output + ")"
@@ -385,10 +416,8 @@ class EfuseMacField(EfuseField):
 
     def save(self, new_value):
         def print_field(e, new_value):
-            print(
-                "    - '{}' ({}) {} -> {}".format(
-                    e.name, e.description, e.get_bitstring(), new_value
-                )
+            log.print(
+                f"    - '{e.name}' ({e.description}) {e.get_bitstring()} -> {new_value}"
             )
 
         if self.name == "CUSTOM_MAC":
@@ -398,18 +427,19 @@ class EfuseMacField(EfuseField):
         else:
             # Writing the BLOCK1 (MAC_SPI_8M_0) default MAC is not possible,
             # as it's written in the factory.
-            raise esptool.FatalError(f"Burning {self.name} is not supported")
+            raise esptool.FatalError(f"Burning {self.name} is not supported.")
 
 
 # fmt: off
 class EfuseKeyPurposeField(EfuseField):
-    key_purpose_len = 5  # bits for key purpose
-    KeyPurposeType = Tuple[str, int, Optional[str], Optional[str], str]
-    KEY_PURPOSES: List[KeyPurposeType] = [
+    KEY_PURPOSES = [
         ("USER",                         0,  None,       None,      "no_need_rd_protect"),   # User purposes (software-only use)
-        ("ECDSA_KEY_P256",               1,  None,       "Reverse", "need_rd_protect"),      # ECDSA key P256
         ("ECDSA_KEY",                    1,  None,       "Reverse", "need_rd_protect"),      # ECDSA key P256
+        ("ECDSA_KEY_P256",               1,  None,       "Reverse", "need_rd_protect"),      # ECDSA key P256
         ("RESERVED",                     1,  None,       None,      "no_need_rd_protect"),   # Reserved
+        ("XTS_AES_256_KEY_1",            2,  None,       "Reverse", "need_rd_protect"),      # XTS_AES_256_KEY_1 (flash/PSRAM encryption)
+        ("XTS_AES_256_KEY_2",            3,  None,       "Reverse", "need_rd_protect"),      # XTS_AES_256_KEY_2 (flash/PSRAM encryption)
+        ("XTS_AES_256_KEY",             -1, "VIRTUAL",   None,      "no_need_rd_protect"),   # Virtual purpose splits to XTS_AES_256_KEY_1 and XTS_AES_256_KEY_2
         ("XTS_AES_128_KEY",              4,  None,       "Reverse", "need_rd_protect"),      # XTS_AES_128_KEY (flash/PSRAM encryption)
         ("HMAC_DOWN_ALL",                5,  None,       None,      "need_rd_protect"),      # HMAC Downstream mode
         ("HMAC_DOWN_JTAG",               6,  None,       None,      "need_rd_protect"),      # JTAG soft enable key (uses HMAC Downstream mode)
@@ -419,20 +449,14 @@ class EfuseKeyPurposeField(EfuseField):
         ("SECURE_BOOT_DIGEST1",          10, "DIGEST",   None,      "no_need_rd_protect"),   # SECURE_BOOT_DIGEST1 (Secure Boot key digest)
         ("SECURE_BOOT_DIGEST2",          11, "DIGEST",   None,      "no_need_rd_protect"),   # SECURE_BOOT_DIGEST2 (Secure Boot key digest)
         ("KM_INIT_KEY",                  12, None,       None,      "need_rd_protect"),      # init key that is used for the generation of AES/ECDSA key
+        ("XTS_AES_256_PSRAM_KEY_1",      13, None,       "Reverse", "need_rd_protect"),      # XTS_AES_256_PSRAM_KEY_1 (PSRAM encryption)
+        ("XTS_AES_256_PSRAM_KEY_2",      14, None,       "Reverse", "need_rd_protect"),      # XTS_AES_256_PSRAM_KEY_1 (PSRAM encryption)
+        # ("XTS_AES_256_PSRAM_KEY",        -2, "VIRTUAL",  None,      "no_need_rd_protect"),   # Virtual purpose splits to XTS_AES_256_PSRAM_KEY_1 and XTS_AES_256_PSRAM_KEY_1
         ("XTS_AES_128_PSRAM_KEY",        15, None,       "Reverse", "need_rd_protect"),      # XTS_AES_128_PSRAM_KEY (PSRAM encryption)
         ("ECDSA_KEY_P192",               16, None,       "Reverse", "need_rd_protect"),      # ECDSA key P192
         ("ECDSA_KEY_P384_L",             17, None,       "Reverse", "need_rd_protect"),      # ECDSA key P384 low
         ("ECDSA_KEY_P384_H",             18, None,       "Reverse", "need_rd_protect"),      # ECDSA key P384 high
-        ("ECDSA_KEY_P384",               -3, "VIRTUAL",  None,      "need_rd_protect"),      # Virtual purpose splits to ECDSA_KEY_P384_L and ECDSA_KEY_P384_H
     ]
-    CUSTOM_KEY_PURPOSES: List[KeyPurposeType] = []
-    for id in range(0, 1 << key_purpose_len):
-        if id not in [p[1] for p in KEY_PURPOSES]:
-            CUSTOM_KEY_PURPOSES.append((f"CUSTOM_{id}", id, None, None, "no_need_rd_protect"))
-            CUSTOM_KEY_PURPOSES.append((f"CUSTOM_DIGEST_{id}", id, "DIGEST", None, "no_need_rd_protect"))
-    CUSTOM_KEY_PURPOSES.append(("CUSTOM_MAX", (1 << key_purpose_len) - 1, None, None, "no_need_rd_protect"))
-    CUSTOM_KEY_PURPOSES.append(("CUSTOM_DIGEST_MAX", (1 << key_purpose_len) - 1, "DIGEST", None, "no_need_rd_protect"))
-    KEY_PURPOSES += CUSTOM_KEY_PURPOSES
 # fmt: on
     KEY_PURPOSES_NAME = [name[0] for name in KEY_PURPOSES]
     DIGEST_KEY_PURPOSES = [name[0] for name in KEY_PURPOSES if name[2] == "DIGEST"]
@@ -447,9 +471,9 @@ class EfuseKeyPurposeField(EfuseField):
                 break
         if raw_val.isdigit():
             if int(raw_val) not in [p[1] for p in self.KEY_PURPOSES if p[1] > 0]:
-                raise esptool.FatalError("'%s' can not be set (value out of range)" % raw_val)
+                raise esptool.FatalError(f"'{raw_val}' can not be set (value out of range).")
         else:
-            raise esptool.FatalError("'%s' unknown name" % raw_val)
+            raise esptool.FatalError(f"'{raw_val}' unknown name.")
         return raw_val
 
     def need_reverse(self, new_key_purpose):
@@ -475,4 +499,7 @@ class EfuseKeyPurposeField(EfuseField):
 
     def save(self, new_value):
         raw_val = int(self.check_format(str(new_value)))
+        str_new_value = self.get_name(raw_val)
+        if self.name == "KEY_PURPOSE_5" and str_new_value.startswith("XTS_AES"):
+            raise esptool.FatalError(f"{self.name} can not have {str_new_value} key due to a hardware bug (please see TRM for more details)")
         return super(EfuseKeyPurposeField, self).save(raw_val)
